<?php

namespace Drupal\synhelper\Service;

use Drupal\Core\Config\FileStorage;

/**
 * ParagraphImport class.
 *
 * @internal
 *   For internal usage by the Commerce synhelper module.
 */
class MenuImport implements ContentImportInterface {

  /**
   * Import Menu.
   */
  public function import(string $directory) {
    $sourceMenu = new FileStorage($directory . '/menu');
    foreach ($sourceMenu->listAll() as $file) {
      $data = $sourceMenu->read($file);
      if ($menu = \Drupal::entityTypeManager()->getStorage('menu')->load($data['menu']['id'])) {
        $menu->set('label', $data['menu']['label']);
        $menu->set('description', $data['menu']['description']);
        $menu->save();
      }
      else {
        \Drupal::entityTypeManager()->getStorage('menu')->create([
          'uid' => 1,
          'id' => $data['menu']['id'],
          'label' => $data['menu']['label'],
          'description' => $data['menu']['description'],
        ])->save();
      }
      $this->addMenuLink($data['links'], NULL, $data['menu']['id']);
    }
  }

  /**
   * Add Menu Links.
   */
  private function addMenuLink($links, $parent_id, $menu_id) {
    if (empty($links)) {
      return;
    }
    $link = \Drupal::entityTypeManager()->getStorage('menu_link_content');
    foreach ($links as $menu_link) {
      $t = [
        'uid' => 1,
        'title' => $menu_link['title'],
        'link' => ['uri' => $menu_link['uri']],
        'menu_name' => $menu_id,
        'expanded' => $menu_link['expanded'],
        'weight' => $menu_link['weight'],
        'parent' => $parent_id,
        'description' => $menu_link['description'],
      ];
      $children = $menu_link['children'];
      $menu_link = $link->create($t);
      $menu_link->save();
      if (!empty($children[0])) {
        $bundle = $menu_link->bundle();
        $uuid = $menu_link->uuid();
        $parent_id1 = $bundle . ":" . $uuid;
      }
      else {
        $parent_id1 = NULL;
      }
      $this->addMenuLink($children, $parent_id1, $menu_id);
    }
  }

}
