<?php

namespace Drupal\synhelper\Service;

use Drupal\Core\Config\FileStorage;
use Drupal\pathauto\PathautoState;

/**
 * ParagraphImport class.
 *
 * @internal
 *   For internal usage by the Commerce synhelper module.
 */
class NodeImport implements ContentImportInterface {
  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\FilesImport
   */
  protected $filesImport;

  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\TaxonomyImport
   */

  protected $taxonomyImport;
  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\ParagraphImport
   */
  protected $paragraphImport;

  /**
   * Controller constructor.
   */
  public function __construct(
    ContentImportInterface $filesImport,
    ContentImportInterface $paragraphImport,
    ContentImportInterface $taxonomyImport
  ) {
    $this->filesImport = $filesImport;
    $this->paragraphImport = $paragraphImport;
    $this->taxonomyImport = $taxonomyImport;
  }

  /**
   * Import Node.
   *
   * If you need to add a custom image/gallery, attach or taxonomy field,
   *  add a new 'case' to existing ones.
   */
  public function import(string $directory) {
    $sourceNode = new FileStorage($directory . '/nodes');
    foreach ($sourceNode->listAll() as $file) {
      $data = $sourceNode->read($file);
      $storage = \Drupal::entityTypeManager()->getStorage('node');
      foreach ($data as $key => $value) {
        switch ($key) {
          case 'field_image':
          case 'field_gallery':
            $n[$key] = $this->filesImport->importImages($value);
            break;

          case 'field_attach':
            $n[$key] = $this->filesImport->importAttach($value);
            break;

          case 'field_type_service':
          case 'field_object_type':
            $n[$key] = $this->taxonomyImport->importTaxonomyField($value);
            break;

          case 'field_paragraph':
            $n[$key] = $this->paragraphImport->importParagraph($value);
            break;

          default:
            $n[$key] = $value;
            break;
        }
      }
      $n['uid'] = 1;
      $node = $storage->create($n);
      if (!empty($data['field_image_big'])) {
        $node->set('field_image_big', $this->filesImport->importMedia($data['field_image_big']));
      }
      if (!empty($data['path'])) {
        $node->path = [
          'alias' => $data['path'],
          'pathauto' => PathautoState::SKIP,
        ];
      }
      $node->save();
      if (array_key_exists('is_front', $data) && $data['is_front'] == TRUE) {
        $id = $node->id();
        $config = \Drupal::service('config.factory')->getEditable('system.site');
        $config->set('page.front', "/node/$id");
        $config->save();
      }
    }
  }

}
